@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class ImportFilterInfoGui : public MailImporter::FilterInfoGui
 {
 public:
     explicit ImportFilterInfoGui(ImportMailPage *parent);
-    ~ImportFilterInfoGui();
+    ~ImportFilterInfoGui() override;
 
     void setStatusMessage(const QString &status) override;
     void setFrom(const QString &from) override;
