@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -36,7 +36,7 @@ class LIBIMPORTWIZARD_EXPORT AbstractAddressBook : public LibImportWizard::Abstr
     Q_OBJECT
 public:
     AbstractAddressBook();
-    ~AbstractAddressBook();
+    ~AbstractAddressBook() override;
 
 protected:
     void createGroup(const KContacts::ContactGroup &group);
