@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -39,7 +39,7 @@ class LIBIMPORTWIZARD_EXPORT AbstractSettings : public LibImportWizard::Abstract
     Q_OBJECT
 public:
     AbstractSettings();
-    ~AbstractSettings();
+    ~AbstractSettings() override;
 
 protected:
     void addImportInfo(const QString &log) override;
